//: Comment from Nicholas Outram (nicholas.outram@plymouth.ac.uk), Plymouth Univeristy, UK
//:
//: Comment applies to Swift version 3

import Foundation

//: Consider the following enumerated type with associated data
enum Vehicle {
   case car(petrol: Bool, sizeCC: Int)
   case plane(engines : Int)
   case other(String)
   case none
}

//: Let's pick an example
let myJourney : Vehicle = .other("pogo stick")

//: I now want to test what case `myJourney` is.
//:
//: We cannot use the `==` operator because `Vehicle` has associated data. Instead we use `if case` and *simply drop the associated value* with `_` as shown above
if case .other(_) = myJourney {
   print("Somewhere nice?")
} else {
   print("Ok, it's a secret?")
}
//:The above is clear enough once you get used to the syntax. The `_` communicates that a value has been dropped.
//:
//: **However**, Swift 3 allows us to drop the parenthesis altogether and use the following shorthand:
if case .other = myJourney {
   print("Somewhere nice?")
} else {
   print("Ok, it's a secret?")
}
//: *Unlike the previous example, I do wonder if this is a language feature that needs review?*
//:
//: - On face value, reading this code as is there is an assignment operator `=` with nothing apparently being assigned.
//: - It also reads as if `=` should be `==`


